@@ -1,10 +1,11 @@
-# Copyright (c) 1998-2003 by Jonathan Swartz. All rights reserved.
+# Copyright (c) 1998-2005 by Jonathan Swartz. All rights reserved.
 # This program is free software; you can redistribute it and/or modify
 # it under the same terms as Perl itself.
 
 package HTML::Mason::Component::FileBased;
 
 use strict;
+use warnings;
 
 use File::Basename;
 use File::Spec;
@@ -48,3 +49,27 @@ sub assign_runtime_properties {
 }
 
 1;
+
+__END__
+
+=head1 NAME
+
+HTML::Mason::Component::FileBased - Mason File-Based Component Class
+
+=head1 DESCRIPTION
+
+This is a subclass of
+L<HTML::Mason::Component|HTML::Mason::Component>. Mason uses it to
+implement components which are stored in files.
+
+=head1 METHODS
+
+See L<the FILE-BASED METHODS section of
+HTML::Mason::Component|HTML::Mason::Component/FILE-BASED METHODS> for
+documentation.
+
+=head1 SEE ALSO
+
+L<HTML::Mason::Component|HTML::Mason::Component>
+
+=cut
